@@ -341,7 +341,7 @@ def peak_detection(data, delta):
                 mx = this
                 mxpos = i
                 lookformax = True
-    return np.array(maxtab), np.array(mintab)
+    return np.array(maxtab, dtype=object), np.array(mintab, dtype=object)
 
 
 # https://stackoverflow.com/a/37616966/1617563
@@ -357,7 +357,7 @@ def fit_distributions(data, distributions=None):
         st.alpha, st.anglit, st.arcsine, st.beta, st.betaprime, st.bradford, st.burr, st.cauchy,
         st.chi, st.chi2, st.cosine, st.dgamma, st.dweibull, st.erlang, st.expon, st.exponnorm,
         st.exponweib, st.exponpow, st.f, st.fatiguelife, st.fisk, st.foldcauchy, st.foldnorm,
-        st.frechet_l, st.genlogistic, st.genpareto, st.gennorm, st.genexpon, st.genextreme,
+        st.genlogistic, st.genpareto, st.gennorm, st.genexpon, st.genextreme,
         st.gamma, st.gengamma, st.genhalflogistic, st.gilbrat, st.gompertz, st.gumbel_r, st.gumbel_l, st.halfcauchy,
         st.halflogistic, st.halfnorm, st.halfgennorm, st.hypsecant, st.invgamma, st.invgauss, st.invweibull,
         st.johnsonsb, st.johnsonsu, st.ksone, st.kstwobign, st.laplace, st.levy, st.levy_l, st.logistic,
