@@ -14,7 +14,7 @@ INTERVAL = 1000
 RATE = 1
 
 
-def collect_user_blobs(stepsize=10, threshold=0.25, progress_callback=None):
+def collect_user_blobs(stepsize=10, threshold=0, progress_callback=None):
     db = {}
     counter = 0
     for study, trials in TRIALS.items():
@@ -30,7 +30,7 @@ def collect_user_blobs(stepsize=10, threshold=0.25, progress_callback=None):
     return db
 
 
-def generate_user_blobs(loader, stepsize, threshold):
+def generate_user_blobs(loader, stepsize, threshold=None):
     blobs = []
     try:
         while True:
@@ -69,7 +69,7 @@ def get_heatmap(kin, threshold, stepsize=50):
             x, ts = kin.next(stepsize-1)
             x[x > threshold] = 0
             b = np.array(x, dtype=np.uint8)
-            im2, contours, hierarchy = cv2.findContours(b, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_SIMPLE)[-2:]
+            contours, hierarchy = cv2.findContours(b, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_SIMPLE)[-2:]
             contours = sorted(contours, key=lambda con: con.shape[0], reverse=True)[:2]
             cv2.drawContours(y, contours, -1, (1, 0, 0), -1)
             z += y
