@@ -173,8 +173,8 @@ def _db_to_binary(db, thresh=None):
             else:
                 spe1 = spe2 = thresh
 
-        res[key]['speech1'] = (db[key]['speech1'] > spe1).astype(np.int)
-        res[key]['speech2'] = (db[key]['speech2'] > spe2).astype(np.int)
+        res[key]['speech1'] = (db[key]['speech1'] > spe1).astype(int)
+        res[key]['speech2'] = (db[key]['speech2'] > spe2).astype(int)
     return res
 
 
@@ -219,7 +219,7 @@ def erode(data, thresh, signal=1, columns=['speech1', 'speech2']):
     res = data.copy()
     delta = (data.index[1] - data.index[0]).asm8 // 1e6
     for k in columns:
-        res[k] = c5.data.fill_gaps(res[k], signal, res[k] != signal, thresh/delta.astype(np.int))
+        res[k] = c5.data.fill_gaps(res[k], signal, res[k] != signal, thresh/delta.astype(int))
     return res
 
 
